import { GraphQLResolveInfo, GraphQLScalarType, GraphQLScalarTypeConfig } from 'graphql';
export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: any;
}> = {
    [K in keyof T]: T[K];
};
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    JSONObject: any;
    Timestamp: any;
};
export declare type ByronBlockVersionData = {
    __typename?: 'ByronBlockVersionData';
    scriptVersion: Scalars['Int'];
    slotDuration: Scalars['Int'];
    maxBlockSize: Scalars['Int'];
    maxHeaderSize: Scalars['Int'];
    maxTxSize: Scalars['Int'];
    maxProposalSize: Scalars['Int'];
    mpcThd: Scalars['String'];
    heavyDelThd: Scalars['String'];
    updateVoteThd: Scalars['String'];
    updateProposalThd: Scalars['String'];
    updateImplicit: Scalars['String'];
    softforkRule: ByronSoftForkRule;
    txFeePolicy: ByronTxFeePolicy;
    unlockStakeEpoch: Scalars['String'];
};
export declare type ByronGenesis = {
    __typename?: 'ByronGenesis';
    bootStakeholders: Scalars['JSONObject'];
    heavyDelegation: Scalars['JSONObject'];
    startTime: Scalars['Timestamp'];
    nonAvvmBalances: Scalars['JSONObject'];
    blockVersionData: ByronBlockVersionData;
    protocolConsts: ByronProtocolConsts;
    avvmDistr: Scalars['JSONObject'];
};
export declare type ByronProtocolConsts = {
    __typename?: 'ByronProtocolConsts';
    k: Scalars['Int'];
    protocolMagic?: Maybe<Scalars['Int']>;
};
export declare type ByronSoftForkRule = {
    __typename?: 'ByronSoftForkRule';
    initThd: Scalars['String'];
    minThd: Scalars['String'];
    thdDecrement: Scalars['String'];
};
export declare type ByronTxFeePolicy = {
    __typename?: 'ByronTxFeePolicy';
    summand: Scalars['String'];
    multiplier: Scalars['String'];
};
export declare type ExtraEntropy = {
    __typename?: 'ExtraEntropy';
    tag: Scalars['String'];
};
export declare type Genesis = {
    __typename?: 'Genesis';
    byron?: Maybe<ByronGenesis>;
    shelley?: Maybe<ShelleyGenesis>;
};
export declare type ProtocolVersion = {
    __typename?: 'ProtocolVersion';
    major: Scalars['Int'];
    minor: Scalars['Int'];
};
export declare type Query = {
    __typename?: 'Query';
    genesis: Genesis;
};
export declare type ShelleyGenesis = {
    __typename?: 'ShelleyGenesis';
    activeSlotsCoeff: Scalars['Float'];
    epochLength: Scalars['Int'];
    genDelegs?: Maybe<Scalars['JSONObject']>;
    initialFunds: Scalars['JSONObject'];
    maxKESEvolutions: Scalars['Int'];
    maxLovelaceSupply: Scalars['String'];
    networkId: Scalars['String'];
    networkMagic: Scalars['Int'];
    protocolMagicId: Scalars['Int'];
    protocolParams: ShelleyProtocolParams;
    securityParam: Scalars['Int'];
    slotLength: Scalars['Int'];
    slotsPerKESPeriod: Scalars['Int'];
    staking?: Maybe<Staking>;
    systemStart: Scalars['String'];
    updateQuorum: Scalars['Int'];
};
export declare type ShelleyProtocolParams = {
    __typename?: 'ShelleyProtocolParams';
    a0: Scalars['Float'];
    decentralisationParam: Scalars['Int'];
    eMax: Scalars['Int'];
    extraEntropy: ExtraEntropy;
    keyDeposit: Scalars['Int'];
    maxBlockBodySize: Scalars['Int'];
    maxBlockHeaderSize: Scalars['Int'];
    maxTxSize: Scalars['Int'];
    minFeeA: Scalars['Int'];
    minFeeB: Scalars['Int'];
    minPoolCost: Scalars['Int'];
    minUTxOValue: Scalars['Int'];
    nOpt: Scalars['Int'];
    poolDeposit: Scalars['Int'];
    protocolVersion: ProtocolVersion;
    rho: Scalars['Float'];
    tau: Scalars['Float'];
};
export declare type Staking = {
    __typename?: 'Staking';
    pools: Scalars['JSONObject'];
    stake: Scalars['JSONObject'];
};
export declare type WithIndex<TObject> = TObject & Record<string, any>;
export declare type ResolversObject<TObject> = WithIndex<TObject>;
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type LegacyStitchingResolver<TResult, TParent, TContext, TArgs> = {
    fragment: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type NewStitchingResolver<TResult, TParent, TContext, TArgs> = {
    selectionSet: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type StitchingResolver<TResult, TParent, TContext, TArgs> = LegacyStitchingResolver<TResult, TParent, TContext, TArgs> | NewStitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | StitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export declare type IsTypeOfResolverFn<T = {}> = (obj: T, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export declare type ResolversTypes = ResolversObject<{
    Query: ResolverTypeWrapper<{}>;
    Genesis: ResolverTypeWrapper<Genesis>;
    ByronGenesis: ResolverTypeWrapper<ByronGenesis>;
    JSONObject: ResolverTypeWrapper<Scalars['JSONObject']>;
    Timestamp: ResolverTypeWrapper<Scalars['Timestamp']>;
    ByronBlockVersionData: ResolverTypeWrapper<ByronBlockVersionData>;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    String: ResolverTypeWrapper<Scalars['String']>;
    ByronSoftForkRule: ResolverTypeWrapper<ByronSoftForkRule>;
    ByronTxFeePolicy: ResolverTypeWrapper<ByronTxFeePolicy>;
    ByronProtocolConsts: ResolverTypeWrapper<ByronProtocolConsts>;
    ShelleyGenesis: ResolverTypeWrapper<ShelleyGenesis>;
    Float: ResolverTypeWrapper<Scalars['Float']>;
    ShelleyProtocolParams: ResolverTypeWrapper<ShelleyProtocolParams>;
    ExtraEntropy: ResolverTypeWrapper<ExtraEntropy>;
    ProtocolVersion: ResolverTypeWrapper<ProtocolVersion>;
    Staking: ResolverTypeWrapper<Staking>;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
}>;
export declare type ResolversParentTypes = ResolversObject<{
    Query: {};
    Genesis: Genesis;
    ByronGenesis: ByronGenesis;
    JSONObject: Scalars['JSONObject'];
    Timestamp: Scalars['Timestamp'];
    ByronBlockVersionData: ByronBlockVersionData;
    Int: Scalars['Int'];
    String: Scalars['String'];
    ByronSoftForkRule: ByronSoftForkRule;
    ByronTxFeePolicy: ByronTxFeePolicy;
    ByronProtocolConsts: ByronProtocolConsts;
    ShelleyGenesis: ShelleyGenesis;
    Float: Scalars['Float'];
    ShelleyProtocolParams: ShelleyProtocolParams;
    ExtraEntropy: ExtraEntropy;
    ProtocolVersion: ProtocolVersion;
    Staking: Staking;
    Boolean: Scalars['Boolean'];
}>;
export declare type ByronBlockVersionDataResolvers<ContextType = any, ParentType extends ResolversParentTypes['ByronBlockVersionData'] = ResolversParentTypes['ByronBlockVersionData']> = ResolversObject<{
    scriptVersion?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    slotDuration?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxBlockSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxHeaderSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxTxSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxProposalSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    mpcThd?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    heavyDelThd?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updateVoteThd?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updateProposalThd?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updateImplicit?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    softforkRule?: Resolver<ResolversTypes['ByronSoftForkRule'], ParentType, ContextType>;
    txFeePolicy?: Resolver<ResolversTypes['ByronTxFeePolicy'], ParentType, ContextType>;
    unlockStakeEpoch?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type ByronGenesisResolvers<ContextType = any, ParentType extends ResolversParentTypes['ByronGenesis'] = ResolversParentTypes['ByronGenesis']> = ResolversObject<{
    bootStakeholders?: Resolver<ResolversTypes['JSONObject'], ParentType, ContextType>;
    heavyDelegation?: Resolver<ResolversTypes['JSONObject'], ParentType, ContextType>;
    startTime?: Resolver<ResolversTypes['Timestamp'], ParentType, ContextType>;
    nonAvvmBalances?: Resolver<ResolversTypes['JSONObject'], ParentType, ContextType>;
    blockVersionData?: Resolver<ResolversTypes['ByronBlockVersionData'], ParentType, ContextType>;
    protocolConsts?: Resolver<ResolversTypes['ByronProtocolConsts'], ParentType, ContextType>;
    avvmDistr?: Resolver<ResolversTypes['JSONObject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type ByronProtocolConstsResolvers<ContextType = any, ParentType extends ResolversParentTypes['ByronProtocolConsts'] = ResolversParentTypes['ByronProtocolConsts']> = ResolversObject<{
    k?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    protocolMagic?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type ByronSoftForkRuleResolvers<ContextType = any, ParentType extends ResolversParentTypes['ByronSoftForkRule'] = ResolversParentTypes['ByronSoftForkRule']> = ResolversObject<{
    initThd?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    minThd?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    thdDecrement?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type ByronTxFeePolicyResolvers<ContextType = any, ParentType extends ResolversParentTypes['ByronTxFeePolicy'] = ResolversParentTypes['ByronTxFeePolicy']> = ResolversObject<{
    summand?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    multiplier?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type ExtraEntropyResolvers<ContextType = any, ParentType extends ResolversParentTypes['ExtraEntropy'] = ResolversParentTypes['ExtraEntropy']> = ResolversObject<{
    tag?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type GenesisResolvers<ContextType = any, ParentType extends ResolversParentTypes['Genesis'] = ResolversParentTypes['Genesis']> = ResolversObject<{
    byron?: Resolver<Maybe<ResolversTypes['ByronGenesis']>, ParentType, ContextType>;
    shelley?: Resolver<Maybe<ResolversTypes['ShelleyGenesis']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export interface JsonObjectScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['JSONObject'], any> {
    name: 'JSONObject';
}
export declare type ProtocolVersionResolvers<ContextType = any, ParentType extends ResolversParentTypes['ProtocolVersion'] = ResolversParentTypes['ProtocolVersion']> = ResolversObject<{
    major?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    minor?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type QueryResolvers<ContextType = any, ParentType extends ResolversParentTypes['Query'] = ResolversParentTypes['Query']> = ResolversObject<{
    genesis?: Resolver<ResolversTypes['Genesis'], ParentType, ContextType>;
}>;
export declare type ShelleyGenesisResolvers<ContextType = any, ParentType extends ResolversParentTypes['ShelleyGenesis'] = ResolversParentTypes['ShelleyGenesis']> = ResolversObject<{
    activeSlotsCoeff?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    epochLength?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    genDelegs?: Resolver<Maybe<ResolversTypes['JSONObject']>, ParentType, ContextType>;
    initialFunds?: Resolver<ResolversTypes['JSONObject'], ParentType, ContextType>;
    maxKESEvolutions?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxLovelaceSupply?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    networkId?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    networkMagic?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    protocolMagicId?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    protocolParams?: Resolver<ResolversTypes['ShelleyProtocolParams'], ParentType, ContextType>;
    securityParam?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    slotLength?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    slotsPerKESPeriod?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    staking?: Resolver<Maybe<ResolversTypes['Staking']>, ParentType, ContextType>;
    systemStart?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    updateQuorum?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type ShelleyProtocolParamsResolvers<ContextType = any, ParentType extends ResolversParentTypes['ShelleyProtocolParams'] = ResolversParentTypes['ShelleyProtocolParams']> = ResolversObject<{
    a0?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    decentralisationParam?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    eMax?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    extraEntropy?: Resolver<ResolversTypes['ExtraEntropy'], ParentType, ContextType>;
    keyDeposit?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxBlockBodySize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxBlockHeaderSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    maxTxSize?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    minFeeA?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    minFeeB?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    minPoolCost?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    minUTxOValue?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    nOpt?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    poolDeposit?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    protocolVersion?: Resolver<ResolversTypes['ProtocolVersion'], ParentType, ContextType>;
    rho?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    tau?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export declare type StakingResolvers<ContextType = any, ParentType extends ResolversParentTypes['Staking'] = ResolversParentTypes['Staking']> = ResolversObject<{
    pools?: Resolver<ResolversTypes['JSONObject'], ParentType, ContextType>;
    stake?: Resolver<ResolversTypes['JSONObject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType>;
}>;
export interface TimestampScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['Timestamp'], any> {
    name: 'Timestamp';
}
export declare type Resolvers<ContextType = any> = ResolversObject<{
    ByronBlockVersionData?: ByronBlockVersionDataResolvers<ContextType>;
    ByronGenesis?: ByronGenesisResolvers<ContextType>;
    ByronProtocolConsts?: ByronProtocolConstsResolvers<ContextType>;
    ByronSoftForkRule?: ByronSoftForkRuleResolvers<ContextType>;
    ByronTxFeePolicy?: ByronTxFeePolicyResolvers<ContextType>;
    ExtraEntropy?: ExtraEntropyResolvers<ContextType>;
    Genesis?: GenesisResolvers<ContextType>;
    JSONObject?: GraphQLScalarType;
    ProtocolVersion?: ProtocolVersionResolvers<ContextType>;
    Query?: QueryResolvers<ContextType>;
    ShelleyGenesis?: ShelleyGenesisResolvers<ContextType>;
    ShelleyProtocolParams?: ShelleyProtocolParamsResolvers<ContextType>;
    Staking?: StakingResolvers<ContextType>;
    Timestamp?: GraphQLScalarType;
}>;
export declare type IResolvers<ContextType = any> = Resolvers<ContextType>;
//# sourceMappingURL=graphql_types.d.ts.map